/*
 * Copyright (C) 2014-2017 Olzhas Rakhimov
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/// @file version.cc.in
/// Implementations of functions returning
/// the version information
/// of the core and dependencies.
/// Some information is filled by CMake and Git.

#include "version.h"

#include <boost/preprocessor/stringize.hpp>
#include <boost/version.hpp>
#include <libxml++config.h>
#include <libxml/xmlversion.h>

namespace scram {
namespace version {

const char* describe() { return ""; }

const char* build() { return "RelWithDebInfo"; }

const char* core() {
  return "0.13.0";
}

const char* boost() { return BOOST_LIB_VERSION; }

const char* libxmlpp() {
  return BOOST_PP_STRINGIZE(LIBXMLXX_MAJOR_VERSION) "." BOOST_PP_STRINGIZE(
      LIBXMLXX_MINOR_VERSION) "." BOOST_PP_STRINGIZE(LIBXMLXX_MICRO_VERSION);
}

const char* libxml() { return LIBXML_DOTTED_VERSION; }

}  // namespace version
}  // namespace scram
